#!/usr/bin/env perl -w

#################### START POD DOCUMENTATION ##############

=head1 Node

 Package 'Node'

=head2 NAME

 Parsing the PAML Files

=head2 SYNOPSIS

 Node handler

=head2 DESCRIPTION

 Node is a module that identifies and handles all of the sites that are contained 
 within the input PAML files.

=head2 FEEDBACK

 All feedback (bugs, feature enhancements, etc.) are greatly appreciated. 

=head2 AUTHOR

 Danny W. De Kee (dan.dekee@gmail.com)

=head2 METHODS

=cut

package Node;
#use Data::Dumper;

=head3 new

 Title    : new 
 Usage    : $node = new Node();
 Function : creates new object for storing node data
 Returns  : node object
 Argument : none

=cut

sub new {

	my $class = shift;
	my $data  = {
		'_no' 	     => undef,
		'_sites_array' => [],
		'temp_index' => 0,
		'id_ref' =>{} 
	};
	bless ($data,$class);
	return $data;

}

=head3 set_node_no

 Title    : set_node_no 
 Usage    : $node->set_node_no($node_no)
 Function : sets the node number for the object
 Returns  : none
 Argument : $node_no

=cut

sub  set_node_no {
	my $class     = shift;
	$class->{_no} = shift;
}

=head3 add_site

 Title    : add_site 
 Usage    : $node->add_site($site_obj)
 Function : adds site object to the sites array
 Returns  : none
 Argument : $site_obj

=cut

sub  add_site {
	my $class = shift;
	my $site  = shift;
	push(@{$class->{_sites_array}},$site);
	$class->{id_ref}->{$site->get_site_id} = $class->{'temp_index'};
	$class->{'temp_index'}++;
}

=head3 get_site

 Title    : get_site 
 Usage    : $site_obj = $node->get_site($site_no)
 Function : get the site objects based on array position
 Returns  : sites_obj
 Argument : site object array position

=cut

sub get_site{
	my $class = shift;
	return $class->{_sites_array}->[$_[0]];
}               

=head3 get_site_by_id

 Title    : get_site_by_id 
 Usage    : $site_obj = $node->get_site($site_id)
 Function : get the site objects based on site id
 Returns  : sites_obj
 Argument : site_id from site object

=cut

sub get_site_by_id{
	my $class = shift;
	my $site_id = $class->{id_ref}->{$_[0]};
	if (defined($site_id)){
		return $class->{_sites_array}->[$site_id];
	}
	else {
		return undef;
	}
}               

=head3 get_numb_of_sites

 Title    : get_numb_of_sites
 Usage    : $no_of_sites = $node->get_numb_of_sites
 Function : obtain the total number of the sites within the nodes
 Returns  : number of sites stored in the nodes
 Argument : none

=cut

sub get_numb_of_sites {
	my $class = shift;
	my $numbOfnodes = @{$class->{_sites_array}};
	return $numbOfnodes;
}
1;
